<?php

namespace Drupal\formatted_title_ck_editor\Form;

use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Drupal\Component\Utility\Html;

/**
 * Defines a form that configures formatted_title_ck_editor’s settings.
 *
 * {@inheritdoc}
 */
class FormattedTitleConfigForm extends ConfigFormBase {
  /**
   * Constructs an AutoParagraphForm object.
   *
   * @param \Drupal\Core\Entity\EntityTypeManagerInterface $entityTypeManager
   *   The entityTypeManager.
   */
  public function __construct(EntityTypeManagerInterface $entityTypeManager) {
    $this->entityTypeManager = $entityTypeManager;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
          $container->get('entity_type.manager')
      );
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'formatted_title_config_form';
  }

  /**
   * {@inheritdoc}
   */
  public function getEditableConfigNames() {
    return [FIELD_TITLE_CONFIG];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->config(FIELD_TITLE_CONFIG);
    $contentTypeList = $this->getContentTypeList();
    $form['content_types'] = [
      '#type' => 'checkboxes',
      '#title' => $this->t('Content Types'),
      '#options' => $contentTypeList,
      '#empty_option' => $this->t('- Select an existing content type -'),
      '#default_value' => $config->get('content_types', []),
      '#required' => TRUE,
    ];
	
	$form['title_allow_tags'] = array(
      '#type' => 'textfield',
      '#title' => t('Allowed HTML Tags in Title'),
      '#required' => TRUE,
	  '#default_value' => ($config->get('title_allow_tags', '<em>') != "") ? $config->get('title_allow_tags', '<em>') : "<em>",
	  '#description' => 'Thes tags would be passed at title. Enter tags with comma seperated values '.Html::escape('<em>,<b>,<sup>').'  etc'
    );

    return parent::buildForm($form, $form_state);

  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {

    $config = $this->config(FIELD_TITLE_CONFIG);
    $config->set('content_types', $form_state->getValue('content_types'));
    $config->save();
	$config->set('title_allow_tags', $form_state->getValue('title_allow_tags'));
    $config->save();
    parent::submitForm($form, $form_state);
  }

  /**
   * Returns a list of all the content types currently installed.
   *
   * @return array
   *   An array of content types.
   */
  public function getContentTypeList() {
    $types = [];
    $contentTypes = (array) $this->entityTypeManager->getStorage('node_type')->loadMultiple();
    foreach ($contentTypes as $contentType) {
      $types[$contentType->id()] = $contentType->label();
    }
    return $types;
  }

}
